package vn.com.seabank.biz.web.rest;

import com.codahale.metrics.annotation.Timed;
import com.swib.services.utils.SwibUtils;
import com.swib.services.web.rest.util.HeaderUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import vn.com.seabank.biz.constants.SwibConstants;
import vn.com.seabank.biz.domain.FTTemplate;
import vn.com.seabank.biz.service.P1107TemplateService;

import javax.inject.Inject;
import javax.servlet.http.HttpServletRequest;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * REST controller for managing ForgetPassword.
 */
@RestController
@RequestMapping("/api")
public class P1107TemplateResource {

    private final Logger log = LoggerFactory.getLogger(P1107TemplateResource.class);

    private static final String ENTITY_NAME = "template";

    private final P1107TemplateService templateService;

    @Inject
    private SwibUtils swibUtils;

    public P1107TemplateResource(P1107TemplateService templateService) {
        this.templateService = templateService;
    }

    /**
     * POST  /ftTemplate : Create a new template.
     *
     * @param ftTemplate the forgetPassword to create
     * @return the ResponseEntity with status 201 (Created) and with body the new forgetPassword, or with status 400 (Bad Request) if the forgetPassword has already an ID
     * @throws URISyntaxException if the Location URI syntax is incorrect
     */
    @RequestMapping(value = "/template",
            method = RequestMethod.POST,
            produces = MediaType.APPLICATION_JSON_VALUE)
    @Timed
    public ResponseEntity<FTTemplate> createTempalte(HttpServletRequest request, @RequestBody FTTemplate ftTemplate) throws URISyntaxException {
        log.debug("REST request to save ftTemplate : {}", ftTemplate);
        if (ftTemplate.getFtTemplateId() != null) {
            return ResponseEntity.badRequest().headers(HeaderUtil.createFailureAlert(ENTITY_NAME, "idexists", "A new forgetPassword cannot already have an ID")).body(new FTTemplate());
        }
        FTTemplate result = templateService.save(creatRequestParams(request), ftTemplate);
        return ResponseEntity.created(new URI("/api/template/" + result.getFtTemplateId()))
                .headers(HeaderUtil.createEntityCreationAlert(ENTITY_NAME, result.getFtTemplateId().toString()))
                .body(result);
    }

    /**
     * PUT  /template: Updates an existing template.
     *
     * @param ftTemplate the forgetPassword to update
     * @return the ResponseEntity with status 200 (OK) and with body the updated forgetPassword,
     * or with status 400 (Bad Request) if the forgetPassword is not valid,
     * or with status 500 (Internal Server Error) if the forgetPassword couldn't be updated
     * @throws URISyntaxException if the Location URI syntax is incorrect
     */
    @RequestMapping(value = "/template",
            method = RequestMethod.PUT,
            produces = MediaType.APPLICATION_JSON_VALUE)
    @Timed
    public ResponseEntity<FTTemplate> updateTemplate(HttpServletRequest request, @RequestBody FTTemplate ftTemplate) throws URISyntaxException {
        log.debug("REST request to update ftTemplate : {}", ftTemplate);
        if (ftTemplate.getFtTemplateId() == null) {
            return createTempalte(request, ftTemplate);
        }
        FTTemplate result = templateService.save(creatRequestParams(request), ftTemplate);
        return ResponseEntity.ok()
                .headers(HeaderUtil.createEntityUpdateAlert(ENTITY_NAME, ftTemplate.getFtTemplateId().toString()))
                .body(result);
    }

    @RequestMapping(
            value = "/template/listTemplate",
            method = RequestMethod.POST,
            produces = MediaType.APPLICATION_JSON_VALUE)
    @Timed
    public ResponseEntity<List> getListTemplate(HttpServletRequest request, @RequestBody FTTemplate ftTemplate) throws Exception {
        List list = templateService.getListTemplate(creatRequestParams(request), ftTemplate);
        return new ResponseEntity<>(list, HttpStatus.OK);
    }


    Map<String, String> creatRequestParams(HttpServletRequest request) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put(SwibConstants.API_HEADER_CUSTOMER_ID, swibUtils.getCustomerId(request));
        reqMap.put(SwibConstants.API_HEADER_USER_ID, swibUtils.getUserName(request));
        return reqMap;
    }

}
